@@ -544,11 +544,14 @@ class BaseInlineFormSetWithAddMoreButton(BaseInlineFormSet):
 <script src="https://maxcdn.bootstrapcdn.com/bootstrap/4.0.0/js/bootstrap.min.js">
         <script>
     $('#{button_id}').click(function() {{
-        var form_idx = $('#{self.prefix}-TOTAL_FORMS').val();
-        $('#{div_name}').append($('#{empty_form_id}').html().replace(/__prefix__/g, form_idx));
-        $('#{self.prefix}-TOTAL_FORMS').val(parseInt(form_idx) + 1);
+        var form_idx = $('#id_{self.prefix}-TOTAL_FORMS').val();
+        var empty_form = document.getElementById('{empty_form_id}).innerHTML.replace(/__prefix__/g, form_idx);        
+        var d1 = document.getElementById('{div_name}');
+        d1.insertAdjacentHTML('afterend', empty_form);
+        $('#id_{self.prefix}-TOTAL_FORMS').val(parseInt(form_idx) + 1);
     }});
 </script>"""
+        print(p)
         return p
 
 
